@@ -207,6 +207,29 @@ def get_split_data_v2(**kwargs):
     }
 
 
+def get_split_data_v2_complete():
+    return [
+        {
+            'id': 'c_1',
+            'tipo': 'Tipo c1',
+            'codice': 'Codice c1',
+            'descrizione': 'Descrizione c1',
+            'importo': 16.0,
+            'capitolo_bilancio': 'Capitolo di bilancio c1',
+            'accertamento': 'Accertamento c1',
+        },
+        {
+            'id': 'c_2',
+            'tipo': 'Tipo c2',
+            'codice': 'Codice c2',
+            'descrizione': 'Descrizione c12',
+            'importo': 0.5,
+            'capitolo_bilancio': 'Capitolo di bilancio c2',
+            'accertamento': 'Accertamento c2',
+        },
+    ]
+
+
 def get_payer_data(**kwargs):
     return {
         'type': 'human',
