@@ -127,6 +127,7 @@ class PaymentTestCase(TestCase):
 
     def test_encoders(self):
         payment = Payment(**get_payment_event_data())
+        validated_split = payment.payment.split
 
         payment_data_v2 = payment.payment
         payment_data_v2.set_split(get_split_data_v2())
@@ -149,6 +150,7 @@ class PaymentTestCase(TestCase):
         payer = Payer(**get_payer_data())
 
         self.assertEqual(json.loads(payment.json())['id'], 'bb7044e4-066c-4bf7-915e-87ee97270eae')
+        self.assertEqual(validated_split, [])
         self.assertEqual(json.loads(payment_v2.json())['payment']['split'], {'c_1': 14.0, 'c_2': None})
         self.assertEqual(
             json.loads(payment_v2_complete.json())['payment']['split'],
